pub struct ConcurrencyLimit<S, A> { /* private fields */ }Expand description
Enforces an adaptive limit on the concurrent number of requests the underlying service can handle.
Unlike a static concurrency limit, ConcurrencyLimit continuously observes
request latency and adjusts the number of allowed in-flight requests using
the configured Algorithm.
Use ConcurrencyLimitLayer to integrate
with [tower::ServiceBuilder].
Implementations
Sourceimpl<S, A> ConcurrencyLimit<S, A>where
A: Algorithm,
impl<S, A> ConcurrencyLimit<S, A>where
A: Algorithm,
Sourcepub fn into_inner(self) -> S
pub fn into_inner(self) -> S
Consumes self, returning the inner service.